# Global variables
utils::globalVariables(
	c(
		"nc", "desc", "BIC_vals",
		"model", "n", "v", "node",
		"P1", "P2"
))
